package com.example.test.view.ui.view.components

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.runtime.Composable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.RadioButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.example.test.domain.utlls.Constant
import com.example.test.model.films
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.launch
import org.w3c.dom.Text


@Composable
fun Insert(navHost: NavHostController) {
    val context = LocalContext.current
    val supabase = Constant.supabase
    val scope = rememberCoroutineScope()

    val filmName = remember { mutableStateOf("") }
    val ratingId = remember { mutableStateOf(1) }
    val genreId = remember { mutableStateOf(1) }
    val fotoUrl = remember { mutableStateOf("") }

    Column(
        modifier = Modifier
            .fillMaxWidth()
            .padding(top = 300.dp, start = 15.dp, end = 15.dp)
            .background(Color.DarkGray.copy(alpha = 0.2f))
            .fillMaxWidth(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        TextField(
            value = filmName.value,
            onValueChange = { filmName.value = it },
            label = { Text("Название фильма", fontSize = 18.sp, color = Color.White) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(Color.White, shape = RoundedCornerShape(8.dp))
                .border(width = 1.dp, color = Color.White, shape = RoundedCornerShape(8.dp))
        )
        Spacer(modifier = Modifier.height(8.dp))
        TextField(
            value = ratingId.value.toString(),
            enabled = false,
            onValueChange = { ratingId.value = it.toInt() },
            label = { Text("Рейтинг", fontSize = 18.sp, color = Color.White) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(Color.White, shape = RoundedCornerShape(8.dp))
                .border(width = 1.dp, color = Color.White, shape = RoundedCornerShape(8.dp))
        )
        Spacer(modifier = Modifier.height(8.dp))
        RatingOptions(ratingId)
        TextField(
            value = genreId.value.toString(),
            enabled = false,
            onValueChange = { genreId.value = it.toInt() },
            label = { Text("Жанр", fontSize = 18.sp, color = Color.White) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(Color.White, shape = RoundedCornerShape(8.dp))
                .border(width = 1.dp, color = Color.White, shape = RoundedCornerShape(8.dp))
        )
        Spacer(modifier = Modifier.height(8.dp))
        RatingOptions(genreId)
        TextField(
            value = fotoUrl.value,
            onValueChange = { fotoUrl.value = it },
            label = { Text("Ссылка на фото", fontSize = 18.sp, color = Color.White) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(Color.White, shape = RoundedCornerShape(8.dp))
                .border(width = 1.dp, color = Color.White, shape = RoundedCornerShape(8.dp))
        )
        Spacer(modifier = Modifier.height(16.dp))
        Button(onClick = {
            scope.launch {
                val count = supabase.from("films").select().data.count()
                val newFilm = films(
                    id = count.toInt() + 1,
                    films_name = filmName.value,
                    foto = fotoUrl.value.ifBlank { null },
                    rating = ratingId.value,
                    genre = genreId.value
                )
                supabase.from("films").insert(newFilm)
            }
        })
        {
            Text("Подтвердить", fontSize = 25.sp, color = Color.White)
        }
        ButtonDefaults.buttonColors(Color.White)
    }
}

@Composable
fun RatingOptions(selectedId: MutableState<Int>) {
    val options = listOf(1, 2, 3, 4, 5)
    Row {
        options.forEach { option ->
            RadioButton(
                selected = selectedId.value == option,
                onClick = { selectedId.value = option },

            )
            Text(option.toString())
            Spacer(modifier = Modifier.width(8.dp))
        }
    }
}