package com.example.test.view.ui.view.components

import android.text.style.BackgroundColorSpan
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.livedata.observeAsState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.NavHostController
import com.example.test.view.ui.view.MainViewModel
import com.example.test.R


@Composable
fun auth(navController: NavController, viewModel: MainViewModel)  {
    val viewModel = MainViewModel()
    val email = remember { mutableStateOf("") }
    val password = remember { mutableStateOf("") }
    var showError = remember { mutableStateOf(false) }
    Column(
        Modifier
            .padding(top = 300.dp, start = 15.dp, end = 15.dp)
            .background(Color.DarkGray.copy(alpha = 0.2f))
            .fillMaxWidth(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally

    ) {
        TextField(
            value = email.value,
            textStyle = TextStyle(fontSize = 25.sp, color = Color.White),
            onValueChange = { newText -> email.value = newText },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(
                    Color.White,
                    shape = RoundedCornerShape(8.dp)
                )
                .border(
                    width = 1.dp,
                    color = Color.White,
                    shape = RoundedCornerShape(8.dp)
                )
        )
        var passwordVisibility: Boolean by remember { mutableStateOf(false) }
        TextField(
            value = password.value,
            visualTransformation = if (passwordVisibility) VisualTransformation.None else PasswordVisualTransformation(),
            leadingIcon = {
                IconButton(onClick = {
                    passwordVisibility = !passwordVisibility
                }) {
                    if (passwordVisibility) {
                        Icon(
                            painter = painterResource(id = R.drawable.baseline_person_24),
                            contentDescription = "",
                            tint = Color.White
                        )
                    } else {
                        Icon(
                            painter = painterResource(id = R.drawable.baseline_person_off_24),
                            contentDescription = "",
                            tint = Color.White
                        )
                    }
                }
            },
            onValueChange = { newText -> password.value = newText },
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = 16.dp)
                .background(
                    Color.White,
                    shape = RoundedCornerShape(8.dp)
                )
                .border(
                    width = 1.dp,
                    color = Color.White,
                    shape = RoundedCornerShape(8.dp)
                )
        )

        Button(onClick = {
            val emailInput = email.value.trim()
            val passwordInput = password.value.trim()
            if (viewModel.onSignInEmailPassword(emailInput, passwordInput)) {
                showError.value = false
                navController.navigate("FilmList")
            } else {
                showError.value = true
            }
        }) {
            Text("Вход", fontSize = 25.sp, color = Color.White)
        }
                ButtonDefaults.buttonColors(Color.White)

        Button(onClick = {
            if (viewModel.onSignUpEmail(email.value, password.value)) {
                showError.value = false
                navController.navigate("FilmList")
            }
            else
            {
                showError.value = true
            }
        }) {
            Text("Регистрация", fontSize = 25.sp, color = Color.White)
        }
                ButtonDefaults.buttonColors(Color.White)
        if (showError.value) {
            Text(
                text = "Неверные данные",
                color = Color.Red,
                fontSize = 18.sp
            )
        }
    }

}

